@@ -12,8 +12,6 @@
  * - Shadow
  *
  * @packageDocumentation
- * @module aws-iot-device-sdk
- * @mergeTarget
  */
 
 import * as iotidentity from './iotidentity/iotidentityclient';
@@ -21,16 +19,24 @@ import * as greengrass from './greengrass/discoveryclient';
 import * as iotjobs from './iotjobs/iotjobsclient';
 import * as iotshadow from './iotshadow/iotshadowclient';
 
-import { mqtt, auth, http, io, iot } from 'aws-crt';
-
-export {
-    iotidentity,
-    greengrass,
-    iotjobs,
-    iotshadow,
-    mqtt,
+import {
     auth,
     http,
     io,
-    iot
+    iot,
+    mqtt,
+    mqtt5
+} from 'aws-crt';
+
+export {
+    auth,
+    greengrass,
+    http,
+    io,
+    iot,
+    iotidentity,
+    iotjobs,
+    iotshadow,
+    mqtt,
+    mqtt5
 }
